@@ -1,11 +1,14 @@
 #!/usr/bin/env -S bash -euo pipefail
 
 projectName="superfile"
-version="v1.4.0"
+version="v1.5.0"
 osList=("darwin" "linux" "windows")
 archList=("amd64" "arm64")
 mkdir dist
 
+# Prevent macOS from adding ._* files to archives
+export COPYFILE_DISABLE=1
+
 for os in "${osList[@]}"; do
     if [ "$os" = "windows" ]; then
         for arch in "${archList[@]}"; do
