@@ -19,6 +19,7 @@ var (
 	Music       = "♬"          // Printable Rune : "♬"
 	Templates   = "\U000f03e2" // Printable Rune : "󰏢"
 	PublicShare = "\uf0ac"     // Printable Rune : ""
+	Trash       = "\uf1f8"     // Printable Rune : ""
 
 	// file operations
 	CompressFile = "\U000f05c4" // Printable Rune : "󰗄"
@@ -108,6 +109,7 @@ var Icons = map[string]Style{
 	"ko":           {Icon: "\uebc6", Color: "#9b59b6"},     // Printable Rune : ""
 	"kt":           {Icon: "\ue634", Color: "#2980b9"},     // Printable Rune : ""
 	"less":         {Icon: "\ue758", Color: "#3498db"},     // Printable Rune : ""
+	"link_file":    {Icon: "\uf481", Color: "NONE"},        // Printable Rune : ""
 	"lock":         {Icon: "\uf023", Color: "#f1c40f"},     // Printable Rune : ""
 	"log":          {Icon: "\uf18d", Color: "#7f8c8d"},     // Printable Rune : ""
 	"lua":          {Icon: "\ue620", Color: "#e74c3c"},     // Printable Rune : ""
@@ -279,6 +281,7 @@ var Aliases = map[string]string{
 	"vhdx":             "iso",
 	"vmdk":             "iso",
 	"jar":              "java",
+	"kts":              "kt",
 	"cjs":              "js",
 	"properties":       "json",
 	"webmanifest":      "json",
@@ -417,6 +420,7 @@ var Folders = map[string]Style{
 	// Item for Generic folder, with key "folder" is initialized in InitIcon()
 	"hidden":       {Icon: "\uf023", Color: "#75715e"}, // Hidden folder - Dark yellowish // Printable Rune : ""
 	"node_modules": {Icon: "\ue5fa", Color: "#cb3837"}, // Node modules folder - Red // Printable Rune : ""
+	"link_folder":  {Icon: "\uf482", Color: "NONE"},    // link folder - None // Printable Rune : ""
 
 	"superfile": {Icon: "\U000f069d", Color: "#FF6F00"}, // Printable Rune : "󰚝"
 }
