@@ -5,6 +5,7 @@ import (
 	"errors"
 	"fmt"
 	"io"
+	"log/slog"
 	"math"
 	"os"
 	"path/filepath"
@@ -16,6 +17,23 @@ import (
 	"github.com/charmbracelet/x/ansi"
 )
 
+// Size calculation constants
+const (
+	KilobyteSize      = 1000 // SI decimal unit
+	KibibyteSize      = 1024 // Binary unit
+	TabWidth          = 4    // Standard tab expansion width
+	DefaultBufferSize = 1024 // Default buffer size for string operations
+	NonBreakingSpace  = 0xa0 // Unicode non-breaking space
+	EscapeChar        = 0x1b // ANSI escape character
+	ASCIIMax          = 0x7f // Maximum ASCII character value
+)
+
+// TODO: This has a bug. Remove its usage. Remove all custom truncation
+// And audit and evaluate any problem
+// The logic truncates to maxChars - len(tails) first, then checks if truncation occurred. This means:
+// - "Hello" with maxChars=5 gets truncated to 2 chars (5-3=2), producing "He..."
+// - "Hello" with maxChars=6 gets truncated to 3 chars (6-3=3), producing "Hel..."
+// Both cases are wrong - "Hello" fits within 5 and 6 characters, so it shouldn't be truncated at all.
 func TruncateText(text string, maxChars int, tails string) string {
 	truncatedText := ansi.Truncate(text, maxChars-len(tails), "")
 	if text != truncatedText {
@@ -51,6 +69,7 @@ func TruncateMiddleText(text string, maxChars int, tails string) string {
 		return text
 	}
 
+	//nolint:mnd // standard halving for center truncation
 	halfEllipsisLength := (maxChars - 3) / 2
 	// TODO : Use ansi.Substring to correctly handle ANSI escape codes
 	truncatedText := text[:halfEllipsisLength] + tails + text[utf8.RuneCountInString(text)-halfEllipsisLength:]
@@ -58,31 +77,42 @@ func TruncateMiddleText(text string, maxChars int, tails string) string {
 	return truncatedText
 }
 
-func PrettierName(name string, width int, isDir bool, isSelected bool, bgColor lipgloss.Color) string {
-	style := GetElementIcon(name, isDir, Config.Nerdfont)
-	if isSelected {
-		return StringColorRender(lipgloss.Color(style.Color), bgColor).
-			Background(bgColor).
-			Render(style.Icon+" ") +
-			FilePanelItemSelectedStyle.
-				Render(TruncateText(name, width, "..."))
+func FilePanelItemRenderWithIcon(
+	name string,
+	width int,
+	isDir bool,
+	isLink bool,
+	isSelected bool,
+	bgColor lipgloss.Color,
+) string {
+	style := GetElementIcon(name, isDir, isLink, Config.Nerdfont)
+	iconData := style.Icon + " "
+	filenameWidth := width - ansi.StringWidth(iconData)
+	if filenameWidth <= 0 {
+		// This should never happen, unless there is extremely low size or programming bug
+		slog.Debug("Too low width for rendering file name", "width", width, "filenameWidth", filenameWidth)
+		return ""
 	}
 	return StringColorRender(lipgloss.Color(style.Color), bgColor).
-		Background(bgColor).
-		Render(style.Icon+" ") +
-		FilePanelStyle.Render(TruncateText(name, width, "..."))
+		Background(bgColor).Render(iconData) +
+		FilePanelItemRender(name, filenameWidth, isSelected, bgColor, lipgloss.Left)
+}
+func FilePanelItemRender(data string,
+	width int,
+	isSelected bool,
+	bgColor lipgloss.Color,
+	alignment lipgloss.Position,
+) string {
+	outputData := ansi.Truncate(data, width, "...")
+	style := FilePanelStyle
+	if isSelected {
+		style = FilePanelItemSelectedStyle
+	}
+	return style.Background(bgColor).Width(width).Align(alignment).Render(outputData)
 }
 
-func PrettierDirectoryPreviewName(name string, isDir bool, bgColor lipgloss.Color) string {
-	style := GetElementIcon(name, isDir, Config.Nerdfont)
-	return StringColorRender(lipgloss.Color(style.Color), bgColor).
-		Background(bgColor).
-		Render(style.Icon+" ") +
-		FilePanelStyle.Render(name)
-}
-
-func ClipboardPrettierName(name string, width int, isDir bool, isSelected bool) string {
-	style := GetElementIcon(filepath.Base(name), isDir, Config.Nerdfont)
+func ClipboardPrettierName(name string, width int, isDir bool, isLink bool, isSelected bool) string {
+	style := GetElementIcon(filepath.Base(name), isDir, isLink, Config.Nerdfont)
 	if isSelected {
 		return StringColorRender(lipgloss.Color(style.Color), FooterBGColor).
 			Background(FooterBGColor).
@@ -116,30 +146,30 @@ func FormatFileSize(size int64) string {
 
 	// TODO : Remove duplication here
 	if Config.FileSizeUseSI {
-		unitIndex := int(math.Floor(math.Log(float64(size)) / math.Log(1000)))
-		adjustedSize := float64(size) / math.Pow(1000, float64(unitIndex))
+		unitIndex := int(math.Floor(math.Log(float64(size)) / math.Log(KilobyteSize)))
+		adjustedSize := float64(size) / math.Pow(KilobyteSize, float64(unitIndex))
 		return fmt.Sprintf("%.2f %s", adjustedSize, unitsDec[unitIndex])
 	}
-	unitIndex := int(math.Floor(math.Log(float64(size)) / math.Log(1024)))
-	adjustedSize := float64(size) / math.Pow(1024, float64(unitIndex))
+	unitIndex := int(math.Floor(math.Log(float64(size)) / math.Log(KibibyteSize)))
+	adjustedSize := float64(size) / math.Pow(KibibyteSize, float64(unitIndex))
 	return fmt.Sprintf("%.2f %s", adjustedSize, unitsBin[unitIndex])
 }
 
-// Truncate line lengths and keep ANSI
-func CheckAndTruncateLineLengths(text string, maxLength int) string {
-	lines := strings.Split(text, "\n")
-	var result strings.Builder
-
-	for _, line := range lines {
-		// Replace tabs with spaces
-		expandedLine := strings.ReplaceAll(line, "\t", strings.Repeat(" ", 4))
-		truncatedLine := ansi.Truncate(expandedLine, maxLength, "")
-		result.WriteString(truncatedLine + "\n")
+func GetHelpMenuHotkeyString(hotkeys []string) string {
+	var hotkey strings.Builder
+	for i, key := range hotkeys {
+		if key == "" {
+			continue
+		}
+		if i != 0 {
+			hotkey.WriteString(" | ")
+		}
+		if key == " " {
+			key = "space"
+		}
+		hotkey.WriteString(key)
 	}
-
-	finalResult := strings.TrimRight(result.String(), "\n")
-
-	return finalResult
+	return hotkey.String()
 }
 
 // Separated this out out for easy testing
@@ -180,7 +210,7 @@ func IsTextFile(filename string) (bool, error) {
 	defer file.Close()
 
 	reader := bufio.NewReader(file)
-	buffer := make([]byte, 1024)
+	buffer := make([]byte, DefaultBufferSize)
 	cnt, err := reader.Read(buffer)
 	if err != nil && !errors.Is(err, io.EOF) {
 		return false, err
@@ -204,7 +234,7 @@ func MakePrintableWithEscCheck(line string, allowEsc bool) string { //nolint: go
 		}
 		// It needs to be handled separately since considered a space,
 		// It is multi-byte in UTF-8, But it has zero display width
-		if r == 0xa0 {
+		if r == NonBreakingSpace {
 			sb.WriteRune(r)
 			continue
 		}
@@ -215,13 +245,13 @@ func MakePrintableWithEscCheck(line string, allowEsc bool) string { //nolint: go
 			sb.WriteString("    ")
 			continue
 		}
-		if r == 0x1b {
+		if r == EscapeChar {
 			if allowEsc {
 				sb.WriteRune(r)
 			}
 			continue
 		}
-		if r > 0x7f {
+		if r > ASCIIMax {
 			if unicode.IsSpace(r) && utf8.RuneLen(r) > 1 {
 				// See https://github.com/charmbracelet/x/issues/466
 				// Space chacters spanning more than one bytes are not handled well by
