@@ -5,6 +5,9 @@ import (
 
 	zoxidelib "github.com/lazysegtree/go-zoxide"
 
+	"github.com/yorukot/superfile/src/internal/ui/filemodel"
+
+	"github.com/yorukot/superfile/src/internal/ui/filepanel"
 	"github.com/yorukot/superfile/src/internal/ui/metadata"
 	"github.com/yorukot/superfile/src/internal/ui/processbar"
 	"github.com/yorukot/superfile/src/internal/ui/sidebar"
@@ -19,18 +22,22 @@ import (
 // Maybe we can replace slice of strings with var args - Should we ?
 // TODO: Move the configuration parameters to a ModelConfig struct.
 // Something like `RendererConfig` struct for `Renderer` struct in ui/renderer package
+// Or even better API like varargs lambda function opts
+// which can be WithFooter(), WithXYZ()
+// Lots of improvements are waiting on it
+//   - Allow Sending thumbnailGeneratorNeeded as false to preview.New()
+//     to prevent noise in test logs. Same with imagePreviewer
 func defaultModelConfig(toggleDotFile, toggleFooter, firstUse bool,
-	firstFilePanelDirs []string, zClient *zoxidelib.Client) *model {
+	firstPanelPaths []string, zClient *zoxidelib.Client) *model {
 	return &model{
-		filePanelFocusIndex: 0,
-		focusPanel:          nonePanelFocus,
-		processBarModel:     processbar.New(),
-		sidebarModel:        sidebar.New(),
-		fileMetaData:        metadata.New(),
-		fileModel: fileModel{
-			filePanels:  filePanelSlice(firstFilePanelDirs),
-			filePreview: preview.New(),
-			width:       10,
+		focusPanel:      nonePanelFocus,
+		processBarModel: processbar.New(),
+		sidebarModel:    sidebar.New(),
+		fileMetaData:    metadata.New(),
+		fileModel: filemodel.Model{
+			FilePanels:       filepanel.FilePanelSlice(firstPanelPaths),
+			FilePreview:      preview.New(),
+			SinglePanelWidth: common.DefaultFilePanelWidth,
 		},
 		helpMenu:       newHelpMenuModal(),
 		promptModal:    prompt.DefaultModel(prompt.PromptMinHeight, prompt.PromptMinWidth),
@@ -98,6 +105,21 @@ func getHelpMenuData() []helpMenuModalData { //nolint: funlen // This should be
 			description:    "Open help menu (hotkeylist)",
 			hotkeyWorkType: globalType,
 		},
+		{
+			hotkey:         common.Hotkeys.OpenCommandLine,
+			description:    "Open command line",
+			hotkeyWorkType: globalType,
+		},
+		{
+			hotkey:         common.Hotkeys.OpenSPFPrompt,
+			description:    "Open SPF prompt",
+			hotkeyWorkType: globalType,
+		},
+		{
+			hotkey:         common.Hotkeys.OpenZoxide,
+			description:    "Open zoxide navigation",
+			hotkeyWorkType: globalType,
+		},
 		{
 			subTitle: "Panel navigation",
 		},
@@ -169,6 +191,16 @@ func getHelpMenuData() []helpMenuModalData { //nolint: funlen // This should be
 			description:    "Down",
 			hotkeyWorkType: globalType,
 		},
+		{
+			hotkey:         common.Hotkeys.PageUp,
+			description:    "Page up",
+			hotkeyWorkType: globalType,
+		},
+		{
+			hotkey:         common.Hotkeys.PageDown,
+			description:    "Page down",
+			hotkeyWorkType: globalType,
+		},
 		{
 			hotkey:         common.Hotkeys.ParentDirectory,
 			description:    "Return to parent folder",
@@ -252,6 +284,11 @@ func getHelpMenuData() []helpMenuModalData { //nolint: funlen // This should be
 			description:    "Copy current file or directory path",
 			hotkeyWorkType: globalType,
 		},
+		{
+			hotkey:         common.Hotkeys.CopyPWD,
+			description:    "Copy current working directory",
+			hotkeyWorkType: globalType,
+		},
 		{
 			hotkey:         common.Hotkeys.ExtractFile,
 			description:    "Extract compressed file",
