@@ -5,8 +5,12 @@ import (
 	"fmt"
 	"os"
 	"path/filepath"
+	"strings"
 	"testing"
 
+	tea "github.com/charmbracelet/bubbletea"
+	"github.com/charmbracelet/x/ansi"
+
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 
@@ -91,10 +95,45 @@ func TestBasic(t *testing.T) {
 		// 5 - clipboard is empty
 		// 6 - model's dimenstion
 
-		assert.Equal(t, dir1, m.getFocusedFilePanel().location)
+		assert.Equal(t, dir1, m.getFocusedFilePanel().Location)
 	})
 }
 
+func TestInitialFilePathPositionsCursorWindow(t *testing.T) {
+	curTestDir := t.TempDir()
+	dir1 := filepath.Join(curTestDir, "dir1")
+
+	utils.SetupDirectories(t, curTestDir, dir1)
+
+	var file7 string
+	var file2 string
+	for i := range 10 {
+		f := filepath.Join(dir1, fmt.Sprintf("file%d.txt", i))
+		utils.SetupFiles(t, f)
+		if i == 7 {
+			file7 = f
+		}
+		if i == 2 {
+			file2 = f
+		}
+	}
+
+	m := defaultTestModel(dir1, file2, file7)
+	// View port of 5
+	TeaUpdate(m, tea.WindowSizeMsg{Width: common.MinimumWidth, Height: 10})
+	// Uncomment below to understand the distribution
+	// t.Logf("Heights : %d [%d - [%d] %d]\n", m.fullHeight, m.footerHeight, m.mainPanelHeight,
+	//	panelElementHeight(m.mainPanelHeight))
+	require.Len(t, m.fileModel.FilePanels, 3)
+	assert.Equal(t, dir1, m.fileModel.FilePanels[0].Location)
+	assert.Equal(t, file2, m.fileModel.FilePanels[1].GetFocusedItem().Location)
+	assert.Equal(t, 2, m.fileModel.FilePanels[1].GetCursor())
+	assert.Equal(t, 0, m.fileModel.FilePanels[1].GetRenderIndex())
+	assert.Equal(t, file7, m.fileModel.FilePanels[2].GetFocusedItem().Location)
+	assert.Equal(t, 7, m.fileModel.FilePanels[2].GetCursor())
+	assert.Equal(t, 3, m.fileModel.FilePanels[2].GetRenderIndex())
+}
+
 func TestQuit(t *testing.T) {
 	// Test
 	// 1 - Normal quit
@@ -245,3 +284,67 @@ func TestChooserFile(t *testing.T) {
 		})
 	}
 }
+
+func eventuallyEnsurePreviewContent(t *testing.T, m *model, content string, msgAndArgs ...any) {
+	contains := false
+	assert.Eventually(t, func() bool {
+		contains = strings.Contains(m.fileModel.FilePreview.GetContent(), content)
+		return contains
+	}, DefaultTestTimeout, DefaultTestTick, msgAndArgs...)
+	if !contains {
+		pContent := ansi.Strip(m.fileModel.FilePreview.GetContent())
+		pContent = pContent[:min(len(pContent), 20)]
+		t.Logf("%s was not found in '%s'", content, pContent)
+	}
+}
+
+func TestAsyncPreviewPanelSync(t *testing.T) {
+	curTestDir := t.TempDir()
+
+	originalPreviewWidth := common.Config.FilePreviewWidth
+	common.Config.FilePreviewWidth = 0
+	t.Cleanup(func() {
+		common.Config.FilePreviewWidth = originalPreviewWidth
+	})
+
+	file1, content1 := filepath.Join(curTestDir, "file1.txt"), "File 1 content"
+	file2, content2 := filepath.Join(curTestDir, "file2.txt"), "File 2 content"
+	utils.SetupFilesWithData(t, []byte(content1), file1)
+	utils.SetupFilesWithData(t, []byte(content2), file2)
+
+	m := defaultTestModelWithFilePreview(curTestDir)
+	p := NewTestTeaProgWithEventLoop(t, m)
+
+	// We need to send message via event loop to ensure that preview load command
+	// is actually processed, also we want a size bigger than default
+	// to allow more number of panels
+	p.Send(tea.WindowSizeMsg{Width: 4 * DefaultTestModelWidth, Height: 4 * DefaultTestModelHeight})
+
+	eventuallyEnsurePreviewContent(t, m, content1, "file1 content should load initially")
+	pW := m.fileModel.FilePreview.GetContentWidth()
+
+	// Create two panels
+	splitPanelAsync(p)
+	splitPanelAsync(p)
+	eventuallyEnsurePreviewContent(t, m, content1, "file1 content should reload after new panel")
+
+	assert.NotEqual(t, pW, m.fileModel.FilePreview.GetContentWidth(),
+		"width should change on new panel creation")
+
+	p.Send(tea.KeyMsg{Type: tea.KeyDown})
+	t.Logf("Current element : %s", m.getFocusedFilePanel().GetFocusedItem().Location)
+	eventuallyEnsurePreviewContent(t, m, content2, "content should update to file2")
+
+	p.SendKey(common.Hotkeys.CloseFilePanel[0])
+	eventuallyEnsurePreviewContent(t, m, content1, "content should update to file1 after closing panel")
+
+	// Upscale
+	p.Send(tea.WindowSizeMsg{Width: 8 * DefaultTestModelWidth,
+		Height: 8 * DefaultTestModelHeight})
+	eventuallyEnsurePreviewContent(t, m, content1, "content should update to file1 after resize")
+
+	// Downscale
+	p.Send(tea.WindowSizeMsg{Width: 6 * DefaultTestModelWidth,
+		Height: 6 * DefaultTestModelHeight})
+	eventuallyEnsurePreviewContent(t, m, content1, "content should update to file1 after resize")
+}
