@@ -1,10 +1,12 @@
 package internal
 
 import (
-	"time"
-
 	zoxidelib "github.com/lazysegtree/go-zoxide"
 
+	"github.com/yorukot/superfile/src/internal/ui/clipboard"
+
+	"github.com/yorukot/superfile/src/internal/ui/filemodel"
+
 	"github.com/yorukot/superfile/src/internal/ui/metadata"
 	"github.com/yorukot/superfile/src/internal/ui/notify"
 	"github.com/yorukot/superfile/src/internal/ui/processbar"
@@ -12,14 +14,10 @@ import (
 
 	"github.com/charmbracelet/bubbles/textinput"
 
-	"github.com/yorukot/superfile/src/internal/ui/preview"
 	"github.com/yorukot/superfile/src/internal/ui/prompt"
 	zoxideui "github.com/yorukot/superfile/src/internal/ui/zoxide"
 )
 
-// Type representing the mode of the panel
-type panelMode uint
-
 // Type representing the type of focused panel
 type focusPanelType int
 
@@ -27,9 +25,6 @@ type hotkeyType int
 
 type modelQuitStateType int
 
-// TODO: Convert to integer enum
-type sortingKind string
-
 const (
 	globalType hotkeyType = iota
 	normalType
@@ -44,12 +39,6 @@ const (
 	metadataFocus
 )
 
-// Constants for select mode or browser mode
-const (
-	selectMode panelMode = iota
-	browserMode
-)
-
 const (
 	notQuitting modelQuitStateType = iota
 	quitInitiated
@@ -65,11 +54,11 @@ const (
 // new model in each tea update.
 type model struct {
 	// Main Panels
-	fileModel       fileModel
+	fileModel       filemodel.Model
 	sidebarModel    sidebar.Model
 	processBarModel processbar.Model
+	clipboard       clipboard.Model
 	focusPanel      focusPanelType
-	copyItems       copyItems
 
 	// Modals
 	notifyModel notify.Model
@@ -92,8 +81,7 @@ type model struct {
 	firstUse             bool
 
 	// This entirely disables metadata fetching. Used in test model
-	disableMetadata     bool
-	filePanelFocusIndex int
+	disableMetadata bool
 
 	// Height in number of lines of actual viewport of
 	// main panel and sidebar excluding border
@@ -135,70 +123,4 @@ type typingModal struct {
 	errorMesssage string
 }
 
-// Copied items
-type copyItems struct {
-	items []string
-	cut   bool
-}
-
-/* FILE WINDOWS TYPE START*/
-// Model for file windows
-type fileModel struct {
-	filePanels   []filePanel
-	width        int
-	renaming     bool
-	maxFilePanel int
-	filePreview  preview.Model
-}
-
-// Panel representing a file
-type filePanel struct {
-	cursor             int
-	render             int
-	isFocused          bool
-	location           string
-	sortOptions        sortOptionsModel
-	panelMode          panelMode
-	selected           []string
-	element            []element
-	directoryRecords   map[string]directoryRecord
-	rename             textinput.Model
-	renaming           bool
-	searchBar          textinput.Model
-	lastTimeGetElement time.Time
-}
-
-// Sort options
-type sortOptionsModel struct {
-	width  int
-	height int
-	open   bool
-	cursor int
-	data   sortOptionsModelData
-}
-
-type sortOptionsModelData struct {
-	options  []string
-	selected int
-	reversed bool
-}
-
-// Record for directory navigation
-type directoryRecord struct {
-	directoryCursor int
-	directoryRender int
-}
-
-// Element within a file panel
-type element struct {
-	name      string
-	location  string
-	directory bool
-	metaData  [][2]string
-}
-
-/* FILE WINDOWS TYPE END*/
-
 type editorFinishedMsg struct{ err error }
-
-type sliceOrderFunc func(i, j int) bool
