@@ -36,6 +36,13 @@ const (
 
 	defaultTestWidth     = 100
 	defaultTestMaxHeight = 100
+
+	// UI dimension constants for prompt modal
+	// promptInputPadding is total padding for prompt input fields
+	promptInputPadding = 6 // 2 + 1 + 2 + 1 (borders and spacing)
+
+	// expectedArgCount is the expected number of prompt arguments
+	expectedArgCount = 2
 )
 
 func modeString(shellMode bool) string {
