@@ -28,61 +28,27 @@ func resolveShellSubstitution(subCmdTimeout time.Duration, command string, cwdLo
 	i := 0
 	for i < len(cmdRunes) {
 		if i+1 < len(cmdRunes) && cmdRunes[i] == '$' {
-			switch cmdRunes[i+1] {
-			// ${ spotted
-			case '{':
-				// Look for Ending '}'
-				end := findEndingBracket(cmdRunes, i+1, '{', '}')
-				if end == -1 {
-					return "", errors.New("unexpected error in tokenization")
-				}
-				if end == len(cmdRunes) {
-					return "", curlyBracketMatchError()
-				}
-
-				envVarName := string(cmdRunes[i+2 : end])
-
-				// We can add a layer of abstraction for better unit testing
-				value, ok := os.LookupEnv(envVarName)
-				if !ok {
-					return "", envVarNotFoundError{varName: envVarName}
-				}
-				// Might Handle values being too big, or having multiple lines
-				// But this is based on user input, so it is probably okay for now
-				// Same comment for command substitution
-				resCommand.WriteString(value)
-
-				i = end + 1
-			case '(':
-				// Look for ending ')'
-				end := findEndingBracket(cmdRunes, i+1, '(', ')')
-				if end == -1 {
-					return "", errors.New("unexpected error in tokenization")
-				}
-
-				if end == len(cmdRunes) {
-					return "", roundBracketMatchError()
-				}
-
-				subCmd := string(cmdRunes[i+2 : end])
-				retCode, output, err := utils.ExecuteCommandInShell(subCmdTimeout, cwdLocation, subCmd)
-
-				if retCode == -1 {
-					return "", fmt.Errorf("could not execute shell substitution command : %s : %w", subCmd, err)
-				}
-				// We are allowing commands that exit with non zero status code
-				// We still use its output
-				if retCode != 0 {
-					slog.Debug("substitution command exited with non zero status", "retCode", retCode,
-						"command", subCmd)
-				}
-				resCommand.WriteString(output)
-
-				i = end + 1
-			default:
+			if !isOpenBracket(cmdRunes[i+1]) {
 				resCommand.WriteRune(cmdRunes[i])
 				i++
+				continue
 			}
+			openChar := cmdRunes[i+1]
+			closeChar := getClosingBracket(openChar)
+			end := findEndingBracket(cmdRunes, i+1, openChar, closeChar)
+			if end == -1 {
+				return "", errors.New("unexpected error in tokenization")
+			}
+			if end == len(cmdRunes) {
+				return "", bracketMatchError{openChar: openChar, closeChar: closeChar}
+			}
+
+			err := updateResCommand(&resCommand, openChar, string(cmdRunes[i+2:end]),
+				subCmdTimeout, cwdLocation)
+			if err != nil {
+				return "", err
+			}
+			i = end + 1
 		} else {
 			resCommand.WriteRune(cmdRunes[i])
 			i++
@@ -92,6 +58,37 @@ func resolveShellSubstitution(subCmdTimeout time.Duration, command string, cwdLo
 	return resCommand.String(), nil
 }
 
+func updateResCommand(resCommand *strings.Builder, openChar rune, token string,
+	subCmdTimeout time.Duration, cwdLocation string) error {
+	switch openChar {
+	case '{':
+		value, ok := os.LookupEnv(token)
+		if !ok {
+			return envVarNotFoundError{varName: token}
+		}
+		// Might Handle values being too big, or having multiple lines
+		// But this is based on user input, so it is probably okay for now
+		// Same comment for command substitution
+		resCommand.WriteString(value)
+	case '(':
+		retCode, output, err := utils.ExecuteCommandInShell(subCmdTimeout, cwdLocation, token)
+
+		if retCode == -1 {
+			return fmt.Errorf("could not execute shell substitution command : %s : %w", token, err)
+		}
+		// We are allowing commands that exit with non zero status code
+		// We still use its output
+		if retCode != 0 {
+			slog.Debug("substitution command exited with non zero status", "retCode", retCode,
+				"command", token)
+		}
+		resCommand.WriteString(output)
+	default:
+		return fmt.Errorf("unexpected openChar %v in tokenization", openChar)
+	}
+	return nil
+}
+
 func findEndingBracket(r []rune, openIdx int, openParan rune, closeParan rune) int {
 	if openIdx < 0 || openIdx >= len(r) || r[openIdx] != openParan {
 		return -1
@@ -100,9 +97,10 @@ func findEndingBracket(r []rune, openIdx int, openParan rune, closeParan rune) i
 	openCount := 1
 	i := openIdx + 1
 	for i < len(r) && openCount != 0 {
-		if r[i] == openParan {
+		switch r[i] {
+		case openParan:
 			openCount++
-		} else if r[i] == closeParan {
+		case closeParan:
 			openCount--
 		}
 		if openCount != 0 {
@@ -112,6 +110,26 @@ func findEndingBracket(r []rune, openIdx int, openParan rune, closeParan rune) i
 	return i
 }
 
+func isOpenBracket(r rune) bool {
+	switch r {
+	case '(', '{':
+		return true
+	default:
+		return false
+	}
+}
+
+func getClosingBracket(r rune) rune {
+	switch r {
+	case '(':
+		return ')'
+	case '{':
+		return '}'
+	default:
+		return ' '
+	}
+}
+
 // splits command into tokens while respecting quotes and escapes
 func tokenizeWithQuotes(command string) ([]string, error) {
 	var (
