@@ -31,5 +31,5 @@ func ReadBoolFile(path string, defaultValue bool) bool {
 }
 
 func WriteBoolFile(path string, value bool) error {
-	return os.WriteFile(path, []byte(strconv.FormatBool(value)), 0644)
+	return os.WriteFile(path, []byte(strconv.FormatBool(value)), ConfigFilePerm)
 }
