@@ -11,15 +11,6 @@ type TomlLoadError struct {
 	missingFields bool
 }
 
-func NewTomlLoadError(msg string, wrapped error, fatal bool, missing bool) *TomlLoadError {
-	return &TomlLoadError{
-		userMessage:   msg,
-		isFatal:       fatal,
-		missingFields: missing,
-		wrappedError:  wrapped,
-	}
-}
-
 func (t *TomlLoadError) Error() string {
 	res := t.userMessage
 	if t.wrappedError != nil {
