@@ -6,10 +6,11 @@ import (
 	"image"
 	"log/slog"
 	"os"
-	"strconv"
 	"strings"
 
 	"github.com/BourgeoisBear/rasterm"
+
+	"github.com/yorukot/superfile/src/internal/common"
 )
 
 // isKittyCapable checks if the terminal supports Kitty graphics protocol
@@ -82,14 +83,15 @@ func generateKittyClearCommands() string {
 // generatePlacementID generates a unique placement ID based on file path
 func generatePlacementID(path string) uint32 {
 	if len(path) == 0 {
-		return 42 // Default fallback
+		return kittyHashSeed // Default fallback
 	}
 
 	hash := 0
 	for _, c := range path {
-		hash = hash*31 + int(c)
+		hash = hash*kittyHashPrime + int(c)
 	}
-	return uint32(hash&0xFFFF) + 1000 // Ensure it's not 0 and avoid low numbers
+	return uint32(hash&kittyMaxID) + //nolint:gosec // Hash is bounded by kittyMaxID mask before conversion
+		kittyNonZeroOffset
 }
 
 // renderWithKittyUsingTermCap renders an image using Kitty graphics protocol with terminal capabilities
@@ -125,13 +127,13 @@ func (p *ImagePreviewer) renderWithKittyUsingTermCap(img image.Image, path strin
 	if imgRatio > termRatio {
 		dstCols := maxWidth
 		dstRows := int(float64(dstCols*pixelsPerColumn) / imgRatio / float64(pixelsPerRow))
-		opts.DstCols = uint32(dstCols)
-		opts.DstRows = uint32(dstRows)
+		opts.DstCols = uint32(dstCols) //nolint:gosec // Terminal dimensions are bounded by maxWidth/maxHeight
+		opts.DstRows = uint32(dstRows) //nolint:gosec // Terminal dimensions are bounded by maxWidth/maxHeight
 	} else {
 		dstRows := maxHeight
 		dstCols := int(float64(dstRows*pixelsPerRow) * imgRatio / float64(pixelsPerColumn))
-		opts.DstRows = uint32(dstRows)
-		opts.DstCols = uint32(dstCols)
+		opts.DstRows = uint32(dstRows) //nolint:gosec // Terminal dimensions are bounded by maxWidth/maxHeight
+		opts.DstCols = uint32(dstCols) //nolint:gosec // Terminal dimensions are bounded by maxWidth/maxHeight
 	}
 
 	// Write image using Kitty protocol
@@ -139,7 +141,23 @@ func (p *ImagePreviewer) renderWithKittyUsingTermCap(img image.Image, path strin
 		return "", err
 	}
 
-	buf.WriteString("\x1b[1;" + strconv.Itoa(sideAreaWidth) + "H")
+	// TODO: using internal/common package in pkg package is against the standards
+	// We shouldn't use that here.
+	// Other usage of common in `file_preview` should be removed too.
+	// common.VideoExtensions should be moved to fixed_variables
+	// and internal/common/utils shoud move to pkg/utils so that it can
+	// be used by everyone
+
+	// TODO : Ideally we should not need the kitty previewer to be
+	// aware of full modal width and make decisions based on global config
+	// A better solutions than this is needed for it.
+	row := 1
+	col := sideAreaWidth + 1
+	if common.Config.EnableFilePreviewBorder {
+		row++
+		col++
+	}
+	buf.WriteString(fmt.Sprintf("\x1b[%d;%dH", row, col))
 
 	return buf.String(), nil
 }
